==> fred_regal-0.8.0-py3-none-any.whl: regal/search/domain.py <==
"""Client for SearchDomain service."""
from datetime import datetime
from typing import Optional, Sequence

from fred_api.registry.domain import service_search_domain_grpc_pb2_grpc
from fred_api.registry.domain.service_search_domain_grpc_pb2 import SearchDomainHistoryRequest, SearchDomainRequest

from regal.domain import DomainHistoryId, DomainId

from .common import BaseSearchClient, SearchCurrentResult, SearchDecoder, SearchHistoryResult, SearchResults


class SearchDomainClient(BaseSearchClient[DomainId, DomainHistoryId]):
    """SearchDomain service gRPC client."""

    grpc_modules = (service_search_domain_grpc_pb2_grpc,)
    decoder_cls = SearchDecoder[DomainId, DomainHistoryId]
    service = "SearchDomain"
    limit_name = "max_number_of_domains"

    async def search_domain(
        self, query_values: Sequence[str], limit: Optional[int] = None, searched_items: Optional[Sequence[str]] = None
    ) -> SearchResults[SearchCurrentResult[DomainId]]:
        """Search for domains based on query.

        Args:
            query_values: List of strings with searched values. Values can be substrings of domain fqdn.
            limit: Maximum number of returned best results.
            searched_items: List of domain fields that should be included in search.
                If ommited, all the fields will be searched.
                The only valid field for domain is `fqdn`.
        """
        return await self.search_object(
            request=SearchDomainRequest(),
            method="search_domain",
            query_values=query_values,
            limit=limit,
            searched_items=searched_items,
        )

    async def search_domain_history(
        self,
        query_values: Sequence[str],
        limit: Optional[int] = None,
        searched_items: Optional[Sequence[str]] = None,
        start: Optional[datetime] = None,
        end: Optional[datetime] = None,
    ) -> SearchResults[SearchHistoryResult[DomainId, DomainHistoryId]]:
        """Search for domains history versions based on query.

        Args:
            query_values: List of strings with searched values. Values can be substrings of domain fqdn.
            limit: Maximum number of returned best results.
            searched_items: List of domain fields that should be included in search.
                If ommited, all the fields will be searched.
                The only valid field for domain is `fqdn`.
            start: Search domain throughout history starting with this datetime.
                If ommited, there is no lower limit on data age.
            end: Search domain throughout history ending with this datetime.
                If ommited, search all the way to current data.

        Raises:
            InvalidHistoryInterval: In case of invalid history interval.
        """
        return await self.search_object_history(
            request=SearchDomainHistoryRequest(),
            method="search_domain_history",
            query_values=query_values,
            limit=limit,
            searched_items=searched_items,
            start=start,
            end=end,
        )

==> fred_regal-1.2.0-py3-none-any.whl: regal/search/domain.py <==
"""Client for SearchDomain service."""
from datetime import datetime
from typing import Optional, Sequence

from fred_api.registry.domain import service_search_domain_grpc_pb2_grpc
from fred_api.registry.domain.service_search_domain_grpc_pb2 import SearchDomainHistoryRequest, SearchDomainRequest
from fred_types import DomainHistoryId, DomainId

from .common import BaseSearchClient, SearchCurrentResult, SearchDecoder, SearchHistoryResult, SearchResults


class SearchDomainClient(BaseSearchClient[DomainId, DomainHistoryId]):
    """SearchDomain service gRPC client."""

    grpc_modules = (service_search_domain_grpc_pb2_grpc,)
    decoder_cls = SearchDecoder[DomainId, DomainHistoryId]
    service = "SearchDomain"
    limit_name = "max_number_of_domains"

    async def search_domain(
        self, query_values: Sequence[str], limit: Optional[int] = None, searched_items: Optional[Sequence[str]] = None
    ) -> SearchResults[SearchCurrentResult[DomainId]]:
        """Search for domains based on query.

        Args:
            query_values: List of strings with searched values. Values can be substrings of domain fqdn.
            limit: Maximum number of returned best results.
            searched_items: List of domain fields that should be included in search.
                If ommited, all the fields will be searched.
                The only valid field for domain is `fqdn`.
        """
        return await self.search_object(
            request=SearchDomainRequest(),
            method="search_domain",
            query_values=query_values,
            limit=limit,
            searched_items=searched_items,
        )

    async def search_domain_history(
        self,
        query_values: Sequence[str],
        limit: Optional[int] = None,
        searched_items: Optional[Sequence[str]] = None,
        start: Optional[datetime] = None,
        end: Optional[datetime] = None,
    ) -> SearchResults[SearchHistoryResult[DomainId, DomainHistoryId]]:
        """Search for domains history versions based on query.

        Args:
            query_values: List of strings with searched values. Values can be substrings of domain fqdn.
            limit: Maximum number of returned best results.
            searched_items: List of domain fields that should be included in search.
                If ommited, all the fields will be searched.
                The only valid field for domain is `fqdn`.
            start: Search domain throughout history starting with this datetime.
                If ommited, there is no lower limit on data age.
            end: Search domain throughout history ending with this datetime.
                If ommited, search all the way to current data.

        Raises:
            InvalidHistoryInterval: In case of invalid history interval.
        """
        return await self.search_object_history(
            request=SearchDomainHistoryRequest(),
            method="search_domain_history",
            query_values=query_values,
            limit=limit,
            searched_items=searched_items,
            start=start,
            end=end,
        )
